/*
  Sample program of ec measurement w/o thermal calibration from jitaku-yasai.com
*/
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <math.h>
#include "ecMeasure.hpp"

float
EcMeasure::FindPeak(int ch, int numshots)
{
  float peakAdcVal = 0.0;

  // input ch check.
  if (ch + 1 > MCP3004_CH_NUM)
  {
    printf("EcMeasure::FindPeak input ch is incorrect %d\n", ch);
    exit(-1);
  }

  for(int i=0; i<numshots; i++)
  {
    float measuredADVal = (float)WriteRead(ch) - MCP3004_RESOLUTION / 2;
    //printf("FindPeak : shot %d value = %4.2f\n", i, measuredADVal);

    if (measuredADVal > peakAdcVal) peakAdcVal = measuredADVal;
  }

  printf("Found Peak : value = %4.2f\n", peakAdcVal);

  return peakAdcVal;
}

float
EcMeasure::GetEC(int numshots)
{
  // Local variables
  float measuredADValCh0 = 0.0, measuredADValCh1 = 0.0;
  float peak;

  // Find peak to measure resitance in stable wave
  // Assume 90% of peak is enough to catch the top.
  peak = FindPeak(MCP3004_CHANNEL1, 100) * 0.9;

  for(int i=0; i<numshots; i++)
  {
    float ADValCh0 = 0.0, ADValCh1 = 0.0;
    while(peak > ADValCh1)
    {
        // CH0. Need to subtract offset for ADC input.
        // The offset point is set to the half resoluton of 10bit ADC
        ADValCh0 = (float)WriteRead(MCP3004_CHANNEL0) - MCP3004_RESOLUTION / 2;
        //printf("ADC CH0 value = %4.2f\n", measuredADValCh0);

        // CH1. Need to subtract offset for ADC input.
        ADValCh1 = (float)WriteRead(MCP3004_CHANNEL1) - MCP3004_RESOLUTION / 2;
        //printf("ADC CH1 value = %4.2f\n", measuredADValCh1);
    }
    measuredADValCh0 += ADValCh0 / (float)numshots;
    measuredADValCh1 += ADValCh1 / (float)numshots;
  }

  // Calculate current.
  // CH0 shows original sin voltage,
  // CH1 shows dropped voltage by resitance for current measument
  // printf("EcMeasure::GetEC CH1 = %4.2f CH2 = %4.2f\n", measuredADValCh0, measuredADValCh1);
  float curret = (measuredADValCh0 - measuredADValCh1) / GetRefResistance();

  // Registance for the measument point
  return measuredADValCh1 / curret;
}

EcMeasure::~EcMeasure()
{
}
