#ifndef _MCP3004_H_
#define _MCP3004_H_
/*
  Sample program of MCP3004 from jitaku-yasai.com
  MCP3004 specification : http://ww1.microchip.com/downloads/en/DeviceDoc/21294E.pdf
*/

#include "type.h"
//                                 01234567
#define MCP3004_START_BIT        0b00000001
#define MCP3004_SGL_BIT          0b10000000
#define MCP3004_DONTCARE         0b01000000 //Don't care for MCP3004
#define MCP3004_CH0_BIT          0b00000000
#define MCP3004_CH1_BIT          0b00010000
#define MCP3004_CH2_BIT          0b00100000
#define MCP3004_CH3_BIT          0b00110000

#define SPI_SPEED                500000       // SPI clock range : 500,000 through 32,000,000
#define MCP3004_CHANNEL0         0
#define MCP3004_CHANNEL1         1
#define MCP3004_CHANNEL2         2
#define MCP3004_CHANNEL3         3
#define MCP3004_CH_NUM           4
#define RP_SPI_CHANNEL0          0            // Raspberry Pi has two SPI channel.
#define DATALEN                  3
#define MCP3004_RESOLUTION       1024

class MCP3004 {

public:
  MCP3004(                                    // Constructor with default value
    uint theChannelOfRP = RP_SPI_CHANNEL0,
    uint theSpiSpeed = SPI_SPEED);
  virtual ~MCP3004();                         // Destructor
  int SPISetUp();                             // SPI setup
  int WriteRead(uint adcCH);                  // Send setting and recieve return value.

private:
  unsigned int  spiSpeed;                     // SPI communication speed
  unsigned char data[DATALEN];                // buffer to send/recieve for SPI communication
  unsigned int  channelOfRP;                  // channel for RP communication
};

#endif
