/*
  Sample program of Thermistor from jitaku-yasai.com
  Thermistor specification : http://akizukidenshi.com/catalog/g/gP-07257/
*/

#include <stdio.h>
#include <unistd.h>
#include <math.h>
#include <wiringPi.h>
#include <wiringPiSPI.h>
#include "thermistor.hpp"

float
Thermistor::GetTemperature(int numshots)
{
  // From ADC value, culculate thermistar resistance.
  float measuredADVal = 0.0;
  for (int i = 0; i < numshots; i++) {
    measuredADVal += (float)WriteRead(MCP3004_CHANNEL2);
  }
  measuredADVal /= (float)numshots;

  // printf("ADC ave value = %4.2f\n", measuredADVal);
  resistance = (MCP3004_RESOLUTION - measuredADVal) / measuredADVal * CONST_R;
  // printf("resistance = %4.2f\n", resistance);

  // Intermediate value derived from resistance
  float calcFromResistance = log(resistance / refResistance) / (CONST_B);

  // Intermediate value from reference temperature of using thermistor
  float calcFromConstTemp = 1.0 / (CONST_T + ABSTEMP);

  // Calculate temperature from Intermediate values
  temperature = 1.0 / (calcFromResistance + calcFromConstTemp) - ABSTEMP;

  return temperature;
}

Thermistor::~Thermistor()
{
}
